import json
import requests
import testdata
import time
from multiprocessing import Process


import pytest


def test_import():
    import testdata


PROTOCOL = 'http'
HOST = 'localhost'
PORT = 1234
TIMEOUT = 1  # seconds


@pytest.fixture()
def server():
    config_raw = json.dumps({
        # 'keys': ['one', 'two', 'three'],
        'keys': './keys.tmp',
        'max-size': '100KB',
        'max-data': 1234,
        'buffer-size': '12MiB',
        'database': './db.json'
    })
    config = testdata.Testdata.Config.model_validate_json(config_raw)

    proc = Process(target=testdata.Testdata(config).run, args=(HOST, PORT))

    proc.start()

    # Wait until webserver becomes available
    start = time.time()
    while (time.time() - start) < TIMEOUT:
        try:
            requests.get(
                f'{PROTOCOL}://{HOST}:{PORT}', timeout=TIMEOUT)
            break
        except requests.exceptions.ConnectionError:
            pass

    yield

    proc.terminate()


def test_webserver(server):

    response = requests.get(
        f'{PROTOCOL}://{HOST}:{PORT}/zeros?api_key=one&size=10B', timeout=TIMEOUT)
    assert response.status_code == 200
    assert response.content == b'\0' * 10
