import sys
import argparse
import json
from os.path import exists

from .testdata import Testdata
from .utils import save_database


def parse_args(args: list[str]):
    parser = argparse.ArgumentParser()
    parser.add_argument('-c', '--config', type=argparse.FileType('r'),
                        default='./config.json', help='Path to config file in JSON format.')
    parser.add_argument('-l', '--listen', type=str,
                        default='0.0.0.0', help='IP on which to listen.')
    parser.add_argument('-p', '--port', type=int,
                        default='8080', help='Port on which to serve the webserver.')

    return parser.parse_args(args)


def run(argv: list[str]) -> None:
    args = parse_args(argv)

    # Load Config
    # config = json.load(args.config)

    config_raw = json.dumps({
        # 'keys': ['one', 'two', 'three'],
        'keys': './keys.tmp',
        'max-size': '100KB',
        'max-data': 1234,
        'buffer-size': '12MiB',
        'database': './db.json'
    })
    config = Testdata.Config.model_validate_json(config_raw)

    if not exists(config.database):
        save_database(config.database, {'data-used': 0})

    Testdata(config).run(args.listen, args.port)


def main() -> None:
    run(sys.argv[1:])
